<?php
/**
 * Created for Schaffen IT.
 * User: Thiago Traczykowski
 */

namespace App\RestApi\Form\Controllers;



use App\RestApi\Form\Requests\FormGroupingRequest;
use App\RestApi\Form\Resources\FormGroupingResource;
use Freelabois\LaravelQuickstart\Traits\Crudable;

use Schaffen\Core\Form\Managers\FormGroupingManager;
use Schaffen\Core\Form\Repositories\FormGroupingRepository;

class FormGroupingController
{
    use Crudable;

    public function __construct(
        FormGroupingManager $manager,
        FormGroupingRepository $repository
    )
    {
        $this->resource = FormGroupingResource::class;
        $this->setup($manager, $repository);
    }

    public function index(FormGroupingRequest $request)
    {
        $params = $request->all();
        $perPage = request()->get('perPage') ?? 45;
        $with = request()->get('with') ?? [];
        $sanitized = request()->except(['perPage', 'with']);
        return $this->resource::collection($this->repository
            ->setOrder(
                isset($params["orderBy"])
                    ? $params["orderBy"]
                    : 'foag_codigo',
                isset($params["orderBy"])
                    ? 'asc'
                    : 'desc')
            ->list($sanitized, $with, $perPage));
    }

    public function store(FormGroupingRequest $request)
    {
        $sanitized = $request->validated();
        return new FormGroupingResource($this->manager->storeOrUpdate($sanitized));
    }

    public function update(FormGroupingRequest $request, int $id)
    {
        $sanitized = $request->validated();
        return new FormGroupingResource($this->manager->storeOrUpdate($sanitized, $id));
    }
}
